﻿using DataTransmission.Enum;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace DataTransmission.Entity
{
	public partial class Workflow : CreationEntity
	{
		public string DefinitionId { get; set; }

		/// <summary>
		/// 流程类型
		/// </summary>
		public EFlowType FlowType { get; set; }

		/// <summary>
		/// 审核结果
		/// </summary>
		public EReviewResult ReviewResult { get; set; }

		#region 业务模块(冗余)

		public string? ModuleId { get; set; }

		public string? ModuleName { get; set; }

		public string? ModuleCode { get; set; }

		#endregion

		/// <summary>
		/// 流程标题
		/// </summary>
		//[SugarColumn(ColumnDataType = "varchar(2000)")]
		public string Title { get; set; }

		/// <summary>
		/// end节点办理完成时间
		/// </summary>
		public DateTime? EndTime { get; set; }

		/// <summary>
		/// 流程状态
		/// </summary>
		public EWorkflowStatus Status { get; set; }

		#region 实际办理信息（节点，部门，意见）

		/// <summary>
		/// 实际办理节点code（会签状态此字段保存最外层会签发起节点code）
		/// </summary>
		public string? ActualHandleStepCode { get; set; }

		/// <summary>
		/// 实际办理节点名称（会签状态此字段保存最外层会签发起节点名称）
		/// </summary>
		public string? ActualHandleStepName { get; set; }

		/// <summary>
		/// 实际办理节点id
		/// </summary>
		public string? ActualHandleStepId { get; set; }

		/// <summary>
		/// 到达实际办理节点时间（stepBox创建时间）
		/// </summary>
		public DateTime? ActualHandleStepCreateTime { get; set; }

		/// <summary>
		/// 实际办理节点签收时间
		/// </summary>
		public DateTime? ActualHandleStepAcceptTime { get; set; }

		/// <summary>
		/// 实际办理时间
		/// </summary>
		public DateTime? ActualHandleTime { get; set; }

		/// <summary>
		/// 实际办理人id
		/// </summary>
		public string? ActualHandlerId { get; set; }

		/// <summary>
		/// 实际办理人名称
		/// </summary>
		public string? ActualHandlerName { get; set; }

		/// <summary>
		/// 实际办理部门名称
		/// </summary>
		public string? ActualHandleOrgName { get; set; }

		/// <summary>
		/// 实际办理部门编码
		/// </summary>
		public string? ActualHandleOrgCode { get; set; }

		/// <summary>
		/// 实际办理部门等级
		/// </summary>
		public int? ActualHandleOrgLevel { get; set; }

		/// <summary>
		/// 实际办理部门行政区划编码
		/// </summary>
		public string? ActualHandleOrgAreaCode { get; set; }

		/// <summary>
		/// 实际办理部门行政区划名称
		/// </summary>
		public string? ActualHandleOrgAreaName { get; set; }

		/// <summary>
		/// 实际办理意见（办理中...or 最终办理意见）
		/// </summary>
		//[SugarColumn(ColumnDataType = "text")]
		public string ActualOpinion { get; set; } = "办理中...";

		///// <summary>
		///// 真实办理人姓名（手动填写）
		///// </summary>
		//public string? RealHandlerName { get; set; }

		///// <summary>
		///// 真实办理人电话（手动填写）
		///// </summary>
		//public string? RealHandlerPhone { get; set; }

		///// <summary>
		///// 沟通方式（手动填写）
		///// </summary>
		//public ERealCommunicationMode? RealCommunicationMode { get; set; }

		///// <summary>
		///// 沟通时间（手动填写）
		///// </summary>
		//public DateTime? RealCommunicationTime { get; set; }

		///// <summary>
		///// 沟通地点（手动填写）
		///// </summary>
		//public string? RealCommunicationAddress { get; set; }

		///// <summary>
		///// 已与市民沟通
		///// </summary>
		//public bool? RealIsContacted { get; set; }

		///// <summary>
		///// 已与市民现场沟通
		///// </summary>
		//public bool? RealContactLocale { get; set; }
		#endregion

		#region 当前办理节点信息(指派时赋值)

		public string? CurrentStepId { get; set; }

		/// <summary>
		/// 当前办理节点code（非会签：当前被指派节点，会签：会签发起节点）
		/// </summary>
		public string? CurrentStepCode { get; set; }

		/// <summary>
		/// 当前节点名称
		/// </summary>
		public string? CurrentStepName { get; set; }

		/// <summary>
		/// 到达当前节点时间
		/// </summary>
		public DateTime? CurrentStepCreateTime { get; set; }

		/// <summary>
		/// 当前办理节点签收时间
		/// </summary>
		public DateTime? CurrentStepAcceptTime { get; set; }

		/// <summary>
		/// 当前办理时间
		/// </summary>
		public DateTime? CurrentHandleTime { get; set; }

		/// <summary>
		/// 当前办理人id
		/// </summary>
		public string? CurrentHandlerId { get; set; }

		/// <summary>
		/// 当前办理人名称
		/// </summary>
		public string? CurrentHandlerName { get; set; }

		/// <summary>
		/// 当前办理部门名称
		/// </summary>
		public string? CurrentHandleOrgName { get; set; }

		/// <summary>
		/// 当前办理部门编码
		/// </summary>
		public string? CurrentHandleOrgId { get; set; }

		/// <summary>
		/// 当前办理部门等级
		/// </summary>
		public int? CurrentHandleOrgLevel { get; set; }

		/// <summary>
		/// 当前办理部门行政区划编码
		/// </summary>
		public string? CurrentHandleOrgAreaCode { get; set; }

		/// <summary>
		/// 当前办理部门行政区划名称
		/// </summary>
		public string? CurrentHandleOrgAreaName { get; set; }

		#endregion

		#region 会签

		/// <summary>
		/// 会签类型
		/// </summary>
		public ECounterSignType? CounterSignType { get; set; }

		/// <summary>
		/// 当前会签办理节点Id，嵌套会签为最外层会签办理节点Id
		/// </summary>
		public string? TopCountersignStepId { get; set; }

		/// <summary>
		/// 流程是否处于会签中（实时）
		/// </summary>
		public bool IsInCountersign { get; set; }

		#endregion


		// /// <summary>
		// /// 办结时长（分钟）
		// /// 办结时间-交办时间
		// /// </summary>
		// public double HandleDuration { get; set; }
		//
		// /// <summary>
		// /// 办结工作日时长
		// /// </summary>
		// public double HandleDurationWorkday { get; set; }

		/// <summary>
		/// 全流程时长（秒）
		/// 归档时间-创建时间
		/// </summary>
		public double AllDuration { get; set; }

		/// <summary>
		/// 外部业务唯一标识
		/// </summary>
		public string ExternalId { get; set; }

		#region 当前办理对象

		/// <summary>
		/// 办理人id
		/// </summary>
		//[SugarColumn(ColumnDataType = "json", IsJson = true)]
		public List<HandlerGroupItem> HandlerUsers { get; set; } = new();

		/// <summary>
		/// 办理部门id
		/// </summary>
		//[SugarColumn(ColumnDataType = "json", IsJson = true)]
		public List<HandlerGroupItem> HandlerOrgs { get; set; } = new();

		#endregion

		#region 流经对象

		/// <summary>
		/// 流经部门
		/// </summary>
		//[SugarColumn(ColumnDataType = "json", IsJson = true)]
		public List<string> FlowedOrgIds { get; set; } = new();

		/// <summary>
		/// 流经办理人
		/// </summary>
		//[SugarColumn(ColumnDataType = "json", IsJson = true)]
		public List<string> FlowedUserIds { get; set; } = new();

		#endregion

		#region 会签实际办理对象

		//[SugarColumn(ColumnDataType = "json", IsJson = true)]
		public List<string>? CsActualHandleOrgIds { get; set; }

		//[SugarColumn(ColumnDataType = "json", IsJson = true)]
		public List<string>? CsActualHandleUserIds { get; set; }

		#endregion

		#region 一级部门

		/// <summary>
		/// 一级部门code
		/// </summary>
		public string? OrgLevelOneCode { get; set; }

		/// <summary>
		/// 一级部门名称
		/// </summary>
		public string? OrgLevelOneName { get; set; }

		#endregion

		#region 受理人(开启流程的话务员)

		/// <summary>
		/// 受理人id
		/// </summary>
		public string? AcceptorId { get; set; }

		/// <summary>
		/// 受理人名称
		/// </summary>
		public string? AcceptorName { get; set; }

		/// <summary>
		/// 受理人工号
		/// </summary>
		public string? AcceptorStaffNo { get; set; }

		/// <summary>
		/// 受理人部门编码
		/// </summary>
		public string? AcceptorOrgId { get; set; }

		/// <summary>
		/// 受理人部门名称
		/// </summary>
		public string? AcceptorOrgName { get; set; }

		/// <summary>
		/// 受理人部门行政区划编码
		/// </summary>
		public string? AcceptorOrgAreaCode { get; set; }

		/// <summary>
		/// 受理人部门行政区划名称
		/// </summary>
		public string? AcceptorOrgAreaName { get; set; }

		#endregion

	}
}
