﻿using SnapshotWinFormsApp.Application.Dtos;
using SnapshotWinFormsApp.Entities.OldHotline;
using SnapshotWinFormsApp.Repository.Interfaces;
using SqlSugar;
using System;
using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace SnapshotWinFormsApp.Repository;

public class SourceRepository<T> : ISourceRepository<T> where T : OldBaseEntity, new()
{
    public SqlSugarClient _db { get; }

    public SourceRepository(CreateInstanceInDto inDto)
    {
        var context = inDto.DbSqlServer;
        _db = context.DbItems.GetValueOrDefault(inDto.Key + "SQLServerDB");
    }

    public T GetById(int id)
    {
        return _db.Queryable<T>().InSingle(id);
    }

    public async Task<List<T>> GetAllAsync(CancellationToken token)
    {
        var sql = string.Empty;
        try
        {
            var query = _db.Queryable<T>();
            sql = query.ToSqlString();
            return await query.ToListAsync(token);

        }
        catch (Exception e)
        {
            var msg = e.Message;
            throw;
        }
    }


    public ISugarQueryable<T> Queryable()
    {
        return _db.Queryable<T>();
    }

    public DataTable GetDataTable(string sql, List<SugarParameter> parameters = null)
    {
        return _db.Ado.GetDataTable(sql, parameters);
    }

    public ISugarQueryable<T> GetBySql(string sql)
    {
        return _db.SqlQueryable<T>(sql);
    }
}
