﻿using DataTransmission.Enum;
using Hotline.Snapshot;
using Mapster;
using SnapshotWinFormsApp.Application.Dtos;
using SnapshotWinFormsApp.Entities.NewHotline;
using SnapshotWinFormsApp.Entities.OldHotline;
using SqlSugar.Extensions;

namespace SnapshotWinFormsApp.Tools;

public static class MapsterConfig
{
    public static void RegisterMappings()
    {
        TypeAdapterConfig<SSP_Volunteer, VolunteerReport>.NewConfig()
            .Map(m => m.JobType, n => n.SV_WorkType)
            .Map(m => m.Name, n => n.SV_Name)
            .Map(m => m.PhoneNumber, n => n.SV_Tel)
            .Map(m => m.VolunteerPhone, n => n.SV_Tel)
            .Map(m => m.Volunteer, n => n.SV_DeclareUserName)
            .Map(m => m.DeclarePhoneNumber, n => n.SV_DeclareUserTel)
            .Map(m => m.IsDeclare, n => n.SV_ISDeclare == "是" ? true : false)
            .Map(m => m.Address, n => n.SV_Address2)
            .Map(m => m.FullAddress, n => n.SV_Address2 + n.SV_Address)
            .Map(m => m.Latitude, n => ParseLatitude(n.SV_latLon))
            .Map(m => m.Longitude, n => ParseLongitude(n.SV_latLon))
            .Map(m => m.IsApprovalProcess, n => n.SV_InspectionItems1 == "是" ? true : false)
            .Map(m => m.IsProfessionalCertificate, n => n.SV_InspectionItems2 == "是" ? true : false)
            .Map(m => m.IsSiteMonitoring, n => n.SV_InspectionItems3 == "是" ? true : false)
            .Map(m => m.IsFireWork, n => n.SV_InspectionItems4 == "是" ? true : false)
            .Map(m => m.IsClearSafety, n => n.SV_InspectionItems5 == "是" ? true : false)
            .Map(m => m.HasFireEquipment, n => n.SV_InspectionItems6 == "是" ? true : false)
            .Map(m => m.IsToolSafety, n => n.SV_InspectionItems7 == "是" ? true : false);

        TypeAdapterConfig<SSP_VolunteerList, Volunteer>.NewConfig()
            .Map(m => m.Name, n => n.SVL_Name)
            .Map(m => m.PhoneNumber, n => n.SVL_Tel);

        TypeAdapterConfig<SSP_AreaUserEntity, Practitioner>.NewConfig()
            .Map(m => m.CreationTime, n => n.InsertTime.ObjToDate())
            .Map(m => m.PhoneNumber, n => n.Tel)
            .Map(m => m.Street, n => n.AreaTown)
            .Map(m => m.SystemAreaName, n => n.AreaName)
            .Map(m => m.Gender, n => n.Sex.Trim() == "男" ? EGender.Male : EGender.Female)
            .Ignore(m => m.Id);

        TypeAdapterConfig<WeChatUserEntity, ThirdAccount>.NewConfig()
            .Map(m => m.UserName, n => n.WUR_WebUserName)
            .Map(m => m.OpenId, n => n.WUR_Openid)
            .Map(m => m.UnIonId, n => n.WUR_unionid)
            .Map(m => m.PhoneNumber, n => n.WUR_PhoneNum)
            .Map(m => m.OldId, n => n.Id)
            .Map(m => m.CreationTime, n => n.WUR_RegDate);

        TypeAdapterConfig<WeChatUserEntity, Citizen>.NewConfig()
            .Map(m => m.CreationTime, n => n.WUR_RegDate)
            .Map(m => m.PhoneNumber, n => n.WUR_PhoneNum)
            .Map(m => m.Name, n => n.WUR_WebUserName);

        TypeAdapterConfig<WeChatUserDto, ThirdAccount>.NewConfig()
            .Map(m => m.PhoneNumber, n => n.WUR_PhoneNum)
            .Map(m => m.UserName, n => n.WUR_WebUserName)
            .Map(m => m.CreationTime, n => n.WUR_RegDate)
            .Map(m => m.OpenId, n => n.WUR_Openid)
            .Map(m => m.UnIonId, n => n.WUR_unionid);

        TypeAdapterConfig<SSP_AreaEntity, CommunityInfo>.NewConfig()
            .Map(m => m.CreationTime, n => n.InsertTime)
            .Map(m => m.Name, n => n.Areaname)
            .Map(m => m.Id, n => n.Areaid)
            .Map(m => m.ParentCode, n => n.Areapid)
            .Map(m => m.DepartmentNo, n => n.Areadepartmentno)
            .Map(m => m.FullName, n => n.Areafullname);

        TypeAdapterConfig<SSP_InviteEntity, InviteCode>.NewConfig()
            .Map(m => m.BeginCode, n => n.SIC_Code)
            .Map(m => m.EndCode, n => n.SIC_Code2)
            .Map(m => m.OrgName, n => n.SIC_BMName)
            .Map(m => m.QRCodeUrl, n => n.SIC_imgUrl);

        TypeAdapterConfig<OldInviteLogEntity, InviteCodeRecord>.NewConfig()
            .Map(m => m.CreationTime, n => n.CreationTime.ObjToDate())
            .Ignore(m => m.Id);

        TypeAdapterConfig<WorkflowDto, Entities.NewHotline.Workflow>.NewConfig()
            .Map(m => m.Title, n => n.FSH_Title)
            //.Map(m => , n => )
            .Ignore(m => m.Id);

        TypeAdapterConfig<OldPublishDto, Entities.NewHotline.OrderPublish>.NewConfig()
            .Map(m => m.No, n => n.FSH_Code)
            .Map(m => m.ArrangeTitle, n => n.FPIA_Title)
            .Map(m => m.ArrangeContent, n => n.FPIA_Content)
            .Map(m => m.ArrangeOpinion, n => n.FPIA_Result)
            .Map(m => m.FeedBackPhone, n => n.FSH_LinkTel)
            .Map(m => m.CreationTime, n => n.FPLT_PubDate.ObjToDate())
            .Map(m => m.CreatorId, n => n.FPLT_PubUserID)
            .Map(m => m.IsContact, n => n.FPIA_CONTACTFLAG == "1")
            .Map(m => m.IsVisited, n => n.FPIA_ASSESSFLAG == "1")
            .Map(m => m.ArrangeOpinion, n => n.FPIA_Result)
            .Ignore(m => m.Id);
    }

    private static double ParseLatitude(string latLon)
    {
        return double.Parse(latLon.Split(',')[0]);
    }

    private static double ParseLongitude(string latLon)
    {
        return double.Parse(latLon.Split(',')[1]);
    }
}
